betty.load module - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.load module

Provide the Ancestry loading API.

class betty.load.LoadAncestryEvent

  Bases: `ProjectEvent`

  Dispatched to load ancestry data into a project.

class betty.load.PostLoadAncestryEvent

  Bases: `ProjectEvent`

  Dispatched to postprocess ancestry data that was loaded into a project.

  This event is invoked immediately after `betty.load.LoadEvent`.

async betty.load.load(project: Project) → None

  Load an ancestry.